@@ -1,21 +1,26 @@
 import logging
 
+from pathlib import Path
 import uvicorn
 from fastapi import FastAPI, HTTPException
+from fastapi.routing import APIRoute
 from starlette.middleware.cors import CORSMiddleware
 
 from rest_api.controller.errors.http_error import http_error_handler
-from rest_api.controller.router import router as api_router
 from rest_api.config import ROOT_PATH
 
+
 logging.basicConfig(format="%(asctime)s %(message)s", datefmt="%m/%d/%Y %I:%M:%S %p")
 logger = logging.getLogger(__name__)
 logging.getLogger("elasticsearch").setLevel(logging.WARNING)
 logging.getLogger("haystack").setLevel(logging.INFO)
 
 
+from rest_api.controller.router import router as api_router
+
+
 def get_application() -> FastAPI:
-    application = FastAPI(title="Haystack-API", debug=True, version="0.1", root_path=ROOT_PATH)
+    application = FastAPI(title="Haystack-API", debug=True, version="0.10", root_path=ROOT_PATH)
 
     # This middleware enables allow all cross-domain requests to the API from a browser. For production
     # deployments, it could be made more restrictive.
@@ -24,18 +29,28 @@ def get_application() -> FastAPI:
     )
 
     application.add_exception_handler(HTTPException, http_error_handler)
-
     application.include_router(api_router)
 
     return application
 
+def use_route_names_as_operation_ids(app: FastAPI) -> None:
+    """
+    Simplify operation IDs so that generated API clients have simpler function
+    names (see https://fastapi.tiangolo.com/advanced/path-operation-advanced-configuration/#using-the-path-operation-function-name-as-the-operationid).
+    The operation IDs will be the same as the route names (i.e. the python method names of the endpoints)
+    Should be called only after all routes have been added.
+    """
+    for route in app.routes:
+        if isinstance(route, APIRoute):
+            route.operation_id = route.name
 
 app = get_application()
+use_route_names_as_operation_ids(app)
 
 logger.info("Open http://127.0.0.1:8000/docs to see Swagger API Documentation.")
 logger.info(
     """
-    Or just try it out directly: curl --request POST --url 'http://127.0.0.1:8000/query' -H "Content-Type: application/json"  --data '{"query": "Did Albus Dumbledore die?"}'
+    Or just try it out directly: curl --request POST --url 'http://127.0.0.1:8000/query' -H "Content-Type: application/json"  --data '{"query": "Who is the father of Arya Stark?"}'
     """
 )
 
