@@ -18,9 +18,8 @@ in the sentence.
 """
 
 
-@pytest.mark.tika
 def test_preprocess_sentence_split():
-    document = {"text": TEXT}
+    document = {"content": TEXT}
     preprocessor = PreProcessor(split_length=1, split_overlap=0, split_by="sentence", split_respect_sentence_boundary=False)
     documents = preprocessor.process(document)
     assert len(documents) == 15
@@ -32,9 +31,8 @@ def test_preprocess_sentence_split():
     assert len(documents) == 2
 
 
-@pytest.mark.tika
 def test_preprocess_word_split():
-    document = {"text": TEXT}
+    document = {"content": TEXT}
     preprocessor = PreProcessor(split_length=10, split_overlap=0, split_by="word", split_respect_sentence_boundary=False)
     documents = preprocessor.process(document)
     assert len(documents) == 11
@@ -43,8 +41,8 @@ def test_preprocess_word_split():
     documents = preprocessor.process(document)
     for i,doc in enumerate(documents):
         if i == 0:
-            assert len(doc["text"].split(" ")) == 14
-        assert len(doc["text"].split(" ")) <= 15 or doc["text"].startswith("This is to trick")
+            assert len(doc["content"].split(" ")) == 14
+        assert len(doc["content"].split(" ")) <= 15 or doc["content"].startswith("This is to trick")
     assert len(documents) == 8
 
     preprocessor = PreProcessor(split_length=40, split_overlap=10, split_by="word", split_respect_sentence_boundary=True)
@@ -56,9 +54,8 @@ def test_preprocess_word_split():
     assert len(documents) == 15
 
 
-@pytest.mark.tika
 def test_preprocess_passage_split():
-    document = {"text": TEXT}
+    document = {"content": TEXT}
     preprocessor = PreProcessor(split_length=1, split_overlap=0, split_by="passage", split_respect_sentence_boundary=False)
     documents = preprocessor.process(document)
     assert len(documents) == 3
@@ -68,7 +65,6 @@ def test_preprocess_passage_split():
     assert len(documents) == 2
 
 
-@pytest.mark.tika
 def test_clean_header_footer():
     converter = PDFToTextConverter()
     document = converter.convert(file_path=Path("samples/pdf/sample_pdf_2.pdf"))  # file contains header/footer
@@ -78,5 +74,5 @@ def test_clean_header_footer():
 
     assert len(documents) == 1
 
-    assert "This is a header." not in documents[0]["text"]
-    assert "footer" not in documents[0]["text"]
\ No newline at end of file
+    assert "This is a header." not in documents[0]["content"]
+    assert "footer" not in documents[0]["content"]
\ No newline at end of file
